@@ -19,6 +19,7 @@
 #include "../src/util.h"
 #include "../src/priv.h"
 #include "http.h"
+#include "zend_exceptions.h"
 
 /* {{{ Private */
 
@@ -165,6 +166,22 @@ PHP_METHOD(EventHttpRequest, __construct)
 }
 /* }}} */
 
+/* {{{ proto int EventHttpRequest::__wakeup()
+   Prevents use of a EventHttpRequest instance that has been unserialized */
+PHP_METHOD(EventHttpRequest, __wakeup)
+{
+	zend_throw_exception_ex(php_event_get_exception(), 0 TSRMLS_CC, "EventHttpRequest instances are not serializable");
+}
+/* }}} */
+
+/* {{{ proto int EventHttpRequest::__sleep()
+   Prevents serialization of a EventHttpRequest instance */
+PHP_METHOD(EventHttpRequest, __sleep)
+{
+	zend_throw_exception_ex(php_event_get_exception(), 0 TSRMLS_CC, "EventHttpRequest instances are not serializable");
+}
+/* }}} */
+
 /* {{{ proto void EventHttpRequest::free(void);
  * Frees the object and removes associated events. */
 PHP_METHOD(EventHttpRequest, free)
